@@ -6,15 +6,11 @@ import sqlparse
 import colemen_file_utils as cfu
 # # from sqlparse import sql
 import utils.string_format as format
-
 import utils.objectUtils as obj
 from pyparsing import And, Suppress,Dict, Word, Literal, Group, Optional, ZeroOrMore, OneOrMore, Regex, restOfLine, alphanums,nums, printables, string, CaselessKeyword,nestedExpr,ParseException,quotedString,removeQuotes,originalTextFor,delimitedList,QuotedString
 
 
 
-
-
-
 def strip_comments(value):
     '''
         Strips single line SQL comments from a string
@@ -43,6 +39,393 @@ def strip_comments(value):
     value = re.sub(r'--[^\n]*\n','',value)
     return value
 
+def strip_sql_quotes(sql):
+    '''
+        Remove all quotes from an sql string.
+        This includes these characters:
+        - Double Quote - "
+        - Single Quote - '
+        - Accent/Tick  - `
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str}
+            The string to strip of quotes.
+
+        Return {str}
+        ----------------------
+        The string without quotations.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 05-31-2022 11:56:37
+        `memberOf`: parse_sql
+        `version`: 1.0
+        `method_name`: strip_sql_quotes
+        @xxx [05-31-2022 11:58:02]: documentation for strip_sql_quotes
+    '''
+
+
+    sql = sql.replace("'",'')
+    sql = sql.replace('"','')
+    sql = sql.replace('`','')
+    return sql
+
+
+def escape_quoted_commas(value,escape_value="__ESCAPED_COMMA__",reverse=False):
+    '''
+        Escape commas that are located within quotes.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str}
+            The string to search within
+        [`escape_value`='__ESCAPED_COMMA__] {str}
+            The value to replace commas with.
+        `reverse` {bool}
+            if True it will replace the escaped commas with actual commas.
+
+        Return {str}
+        ----------------------
+        The string with escaped commas.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-01-2022 06:54:48
+        `memberOf`: parse_sql
+        `version`: 1.0
+        `method_name`: escape_quoted_commas
+        @xxx [06-01-2022 06:57:45]: documentation for escape_quoted_commas
+    '''
+
+    if reverse is True:
+        return value.replace(escape_value,",")
+
+    sql_qs = QuotedString("'", esc_quote="''")
+    quote = sql_qs.search_string(value)
+    if len(quote) > 0:
+        quote = quote.asList()
+        # print(f"quote: {quote}")
+        for q in quote:
+            if len(q) == 1:
+                q = q[0]
+            esc = q.replace(",",escape_value)
+            value = value.replace(q,esc)
+
+    # print(sql_qs.search_string(value))
+    return value
+
+def escape_quoted_chars(value,reverse=False):
+    '''
+        Escape characters that can effect parsing which are located within quotes.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str}
+            The string to search within
+
+        `reverse` {bool}
+            if True it will reverse the escaped chars with their actual chars.
+
+        Return {str}
+        ----------------------
+        The string with escaped chars.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-01-2022 06:54:48
+        `memberOf`: parse_sql
+        `version`: 1.0
+        `method_name`: escape_quoted_chars
+        @xxx [06-01-2022 06:57:45]: documentation for escape_quoted_chars
+    '''
+
+    escapes = [
+        [",","__&#44__"],
+        [";","__&#59__"],
+        ["(","__&#40__"],
+        [")","__&#41__"],
+        ["`","__&#96__"],
+        ['"',"__&#34__"],
+        ["'","__&#39__"],
+    ]
+
+
+    if reverse is True:
+        for e in escapes:
+            value = value.replace(e[1],e[0])
+        return value
+
+    for e in escapes:
+        sql_qs = QuotedString("'", esc_quote="''")
+        quote = sql_qs.search_string(value)
+        if len(quote) > 0:
+            quote = quote.asList()
+            # print(f"quote: {quote}")
+            for q in quote:
+                if len(q) == 1:
+                    q = q[0]
+                esc = q.replace(e[0],e[1])
+                value = value.replace(q,esc)
+    return value
+
+    # print(sql_qs.search_string(value))
+    return value
+
+def parse_column_data(value=None):
+    # TODO []: remove this!!! it is for testing only!!!!!
+    # value = "`timestamp`       int NULL DEFAULT NULL COMMENT 'Timestamp of when the task was created.' ,"
+    _tick,_double_quote,_single_quote,_comma = [Suppress(x) for x in list('`"\',')]
+    _quote = (_tick|_double_quote|_single_quote)
+    _open_paren,_close_paren = [Suppress(x) for x in list('()')]
+    # paren_word = _open_paren + Optional(_quote) + Word(alphanums + "_") + Optional(_quote) + _close_paren
+    quoted_word = _quote + Word(alphanums + "_") + _quote
+
+
+    column_name = quoted_word.setResultsName('name')
+
+
+    ctypes = CaselessKeyword("mediumtext") | CaselessKeyword("mediumblob") | CaselessKeyword("varbinary") | CaselessKeyword("timestamp") | CaselessKeyword("mediumint") | CaselessKeyword("tinytext") | CaselessKeyword("tinyblob") | CaselessKeyword("smallint") | CaselessKeyword("longtext") | CaselessKeyword("longblob") | CaselessKeyword("datetime") | CaselessKeyword("varchar") | CaselessKeyword("tinyint") | CaselessKeyword("integer") | CaselessKeyword("decimal") | CaselessKeyword("boolean") | CaselessKeyword("double") | CaselessKeyword("double") | CaselessKeyword("binary") | CaselessKeyword("bigint") | CaselessKeyword("float") | CaselessKeyword("float") | CaselessKeyword("year") | CaselessKeyword("time") | CaselessKeyword("text") | CaselessKeyword("enum") | CaselessKeyword("date") | CaselessKeyword("char") | CaselessKeyword("bool") | CaselessKeyword("blob") | CaselessKeyword("set") | CaselessKeyword("int") | CaselessKeyword("dec") | CaselessKeyword("bit")
+    ctype_len = Optional(_open_paren + Word(nums) + _close_paren)
+    column_type = ctypes.setResultsName('type') + ctype_len.setResultsName('size')
+
+    null_vals = CaselessKeyword("NULL") | CaselessKeyword("NOT NULL")
+    null_type = null_vals.setResultsName('null_type')
+
+    def_k = Suppress(CaselessKeyword('DEFAULT'))
+    default = Optional(def_k + Word(alphanums))
+    quote = QuotedString("'", esc_quote="''",unquote_results=False).search_string(value)
+    if len(quote) > 0:
+        quote = quote[0][0]
+        default = Optional(default|def_k + quote).setResultsName('default')
+
+    com_k = Suppress(CaselessKeyword('COMMENT'))
+    comment = Optional(com_k + Word(alphanums))
+    quote = QuotedString("'", esc_quote="''",unquote_results=False).search_string(value)
+    if len(quote) > 0:
+        quote = quote[0][0]
+        comment = Optional(com_k + quote).setResultsName('comment')
+
+
+
+    grammar = column_name + column_type + null_type + default + comment
+    res = ZeroOrMore(Group(grammar).setResultsName('data')).parseString(value)
+
+    output = None
+
+    if len(res) > 0:
+        data = res.as_dict()['data']
+        # print(data)
+        defaults = {
+            "name":None,
+            "type":None,
+            "allow_nulls":None,
+            "default":None,
+            "comment":None,
+        }
+        new_data = {}
+        for k,v in data.items():
+            if k == "size":
+                new_data[k] = int(v[0])
+                continue
+            if k == "null_type":
+                if v.upper() == 'NOT NULL':
+                    new_data['allow_nulls'] = False
+                    continue
+                if v.upper() == 'NULL':
+                    new_data['allow_nulls'] = True
+                    continue
+            if isinstance(v,(list)):
+                v = format.strip_any(v[0],["'",'"'])
+                new_data[k] = v
+                continue
+            new_data[k] = v
+
+        # print(new_data)
+        new_data = obj.set_defaults(defaults,new_data)
+        output = new_data
+    return output
+
+
+
+
+def parse_schema_statement(value=None):
+    # TODO []: remove this!!! it is for testing only!!!!!
+    value = "CREATE SCHEMA IF NOT EXISTS `idealech_Equari_Content_Database`;"
+
+
+    _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
+    _quote = (_tick|_double_quote|_single_quote)
+    _open_paren,_close_paren = [Suppress(x) for x in list('()')]
+    # paren_word = _open_paren + Optional(_quote) + Word(alphanums + "_") + Optional(_quote) + _close_paren
+    quoted_word = _quote + Word(alphanums + "_") + _quote
+
+    keys = CaselessKeyword("schema")
+    create_statement = CaselessKeyword("create").setResultsName('action') + keys
+    drop_statement = CaselessKeyword("drop").setResultsName('action') + keys
+    action = drop_statement | create_statement
+
+
+    exists = Optional(CaselessKeyword("if exists") | CaselessKeyword("if not exists")).setResultsName('test')
+    schema_name = quoted_word.setResultsName('schema_name')
+
+
+    grammar = action + exists + schema_name
+    res = ZeroOrMore(Group(grammar).setResultsName('data')).parseString(value)
+
+    output = None
+
+    if len(res) > 0:
+        data = res.as_dict()['data']
+        # print(data)
+        defaults = {
+            "action":None,
+            "test":None,
+            "schema_name":None,
+        }
+        new_data = {}
+        for k,v in data.items():
+            if isinstance(v,(list)):
+                new_data[k] = v[0]
+                continue
+            new_data[k] = v
+        new_data = obj.set_defaults(defaults,new_data)
+        # print(new_data)
+        output = new_data
+    return output
+
+
+
+def parse_table_statement(value=None):
+    # TODO []: remove this!!! it is for testing only!!!!!
+    # value = "DROP TABLE IF EXISTS `idealech_Equari_Management_Database`.`blackholes`;"
+
+    
+
+    _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
+    _quote = (_tick|_double_quote|_single_quote)
+    _open_paren,_close_paren = [Suppress(x) for x in list('()')]
+    # paren_word = _open_paren + Optional(_quote) + Word(alphanums + "_") + Optional(_quote) + _close_paren
+    quoted_word = _quote + Word(alphanums + "_") + _quote
+
+    keys = CaselessKeyword("table")
+    create_statement = CaselessKeyword("create").setResultsName('action') + keys
+    drop_statement = CaselessKeyword("drop").setResultsName('action') + keys
+    action = drop_statement | create_statement
+
+
+    exists = Optional(CaselessKeyword("if exists") | CaselessKeyword("if not exists")).setResultsName('test')
+    table_name = Optional(quoted_word.setResultsName('schema_name') + _period) + quoted_word.setResultsName('table_name')
+
+
+    grammar = action + exists + table_name
+    res = ZeroOrMore(Group(grammar).setResultsName('data')).parseString(value)
+
+    output = None
+
+    if len(res) > 0:
+        data = res.as_dict()['data']
+        # print(data)
+        defaults = {
+            "action":None,
+            "test":None,
+            "schema_name":None,
+            "table_name":None,
+        }
+        new_data = {}
+        for k,v in data.items():
+            if isinstance(v,(list)):
+                new_data[k] = v[0]
+                continue
+            new_data[k] = v
+        new_data = obj.set_defaults(defaults,new_data)
+        if new_data['action'] == "create":
+            cols = capture_create_table_columns(value)
+            # new_data['column_data'] = obj.strip_list_nulls([parse_column_data(x) for x in cols])
+            d = _parse_table_column_lines(cols)
+            new_data["columns"] = d['columns']
+            new_data["primary_keys"] = d['primary_keys']
+            new_data["keys"] = d['keys']
+            new_data["constraints"] = d['constraints']
+        # print(new_data)
+        output = new_data
+    return output
+
+def _parse_table_column_lines(lines):
+    data = {
+        "columns":[],
+        "primary_keys":[],
+        "keys":[],
+        "constraints":[],
+    }
+    # keys = []
+
+    for line in lines:
+        # print(f"line: {line}")
+        if is_line_key(line):
+            # print(f"key found: {line} {parse_key(line)}")
+            data['keys'] = obj.append(data['keys'],parse_key(line))
+            pk = parse_primary_key(line)
+            if pk is not None:
+                data['primary_keys'] = obj.append(data['primary_keys'],pk['primary_key'])
+            # data['primary_keys'] = obj.append(data['primary_keys'],parse_primary_key(line))
+
+        if is_line_constraint(line):
+            data['constraints'] = obj.append(data['constraints'],parse_constraint(line))
+
+
+        data['columns'] = obj.append(data['columns'],parse_column_data(line))
+
+        # parse_column_data(line)
+    # data['keys'] = keys
+    return data
+
+def capture_create_table_columns(sql):
+    '''
+        Used by parse_table_statement to capture the column area of the statement.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `sql` {str}
+            The create table statement to parse.
+
+        Return {list}
+        ----------------------
+        A list of column declarations upon success.
+        The list is empty if nothing is found.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-01-2022 08:48:11
+        `memberOf`: parse_sql
+        `version`: 1.0
+        `method_name`: capture_create_table_columns
+        @xxx [06-01-2022 08:50:01]: documentation for capture_create_table_columns
+    '''
+
+    output = []
+    scanner = originalTextFor(nestedExpr('(',')'))
+    for match in scanner.searchString(sql):
+        val = format.strip_any(match[0],["(",")"])
+        val = escape_quoted_chars(val,True)
+        output = val.split("\n")
+    return output
+# print(parse_table_statement())
+
+
+
 def parse_list(value):
     value = value.asList()
     # print(type(value))
@@ -55,12 +438,12 @@ def parse_list(value):
 def parse_key(value=None):
     if 'key' not in value.lower():
         return None
-    value ="KEY `FK_ActivityLogs_ActivityTypeID` (`activity_type_id`, `activity_type_hash_id`),"
+    # value ="KEY `FK_ActivityLogs_ActivityTypeID` (`activity_type_id`, `activity_type_hash_id`),"
     _tick,_double_quote,_single_quote,_comma = [Suppress(x) for x in list('`"\',')]
     _quote = (_tick|_double_quote|_single_quote)
     _open_paren,_close_paren = [Suppress(x) for x in list('()')]
     # paren_word = _open_paren + Optional(_quote) + Word(alphanums + "_") + Optional(_quote) + _close_paren
-    quoted_word = _quote + Word(alphanums + "_") + _quote    
+    quoted_word = _quote + Word(alphanums + "_") + _quote
 
     paren_word_list = _open_paren + Word(alphanums + "_,'\"` ") + _close_paren
 
@@ -88,13 +471,13 @@ def parse_key(value=None):
 
         # print(new_data)
         output = new_data
-    return output    
+    return output
 
 def parse_primary_key(value=None):
     if 'primary key' not in value.lower():
         return None
     # value = "PRIMARY KEY (`activity_log_id`)"
-    value = "PRIMARY KEY (`activity_type_id`, `activity_type_hash_id`),"
+    # value = "PRIMARY KEY (`activity_type_id`, `activity_type_hash_id`),"
     _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
     _quote = (_tick|_double_quote|_single_quote)
     _open_paren,_close_paren = [Suppress(x) for x in list('()')]
@@ -134,7 +517,7 @@ def parse_constraint(value):
     # constraints = ["ON UPDATE","ON DELETE"]
     # constraint_conds = ["RESTRICT","CASCADE","SET NULL","NO ACTION","SET DEFAULT"]
 
-    
+
     constraint_conditions = (CaselessKeyword('RESTRICT') | CaselessKeyword('CASCADE') | CaselessKeyword('SET NULL') | CaselessKeyword('NO ACTION') | CaselessKeyword('SET DEFAULT'))
 
     # quoted_paren_word = _quote + Word(alphanums + "_") + _quote
@@ -142,7 +525,7 @@ def parse_constraint(value):
     # constraint_name = Suppress(CaselessKeyword('CONSTRAINT')) + _quote + Word(alphanums + "_").setResultsName('constraint_name') + _quote
 
     foreign_key_name = Suppress(CaselessKeyword('FOREIGN KEY')) + quoted_word.setResultsName('foreign_key')
-    local_col_name = paren_word.setResultsName('local_col_name') 
+    local_col_name = paren_word.setResultsName('local_col_name')
     foreign_table = Suppress(CaselessKeyword('REFERENCES')) + Optional(quoted_word.setResultsName('schema_name') + _period) + quoted_word.setResultsName('table_name')
     foreign_col_name = paren_word.setResultsName('foreign_col_name')
 
@@ -206,6 +589,8 @@ def parse_table_columns(sql):
     # orig_sql = sql
     file_data = strip_keys_constraints(sql)
     file_data['columns'] = {}
+    # file_data['sql'] = '\n'.join([escape_quoted_commas(x) for x in "\n".split(file_data['sql'])])
+    # print(f"file_data['sql']: {file_data['sql']}")
 
     # sql = parse_primary_keys(sql)
 
@@ -255,18 +640,19 @@ def parse_table_columns(sql):
                         "shlexed":None,
                         "is_primary_key":False,
                     }
+                    # print (f"raw_type: {data['raw_type']}")
                     data['shlexed'] = shlex.split(data['raw_type'])
                     data = prep_shlexed(data)
                     # print (f"column: {c_name}")
-                    # print (f"type: {c_type}")
                     if data['name'] in file_data['primary_keys']:
                         data['is_primary_key'] = True
                     data = parse_col_type(data)
                     data = parse_allow_null(data)
                     data = parse_col_comment(data)
-                    
-                    
-                    del data['shlexed']
+
+
+
+                    # del data['shlexed']
                     cols[c_name] = data
                 # print ("---"*20)
                 break
@@ -303,9 +689,10 @@ def prep_shlexed(col_data):
         @xxx [05-31-2022 07:56:12]: documentation for prep_shlexed
     '''
 
-    
+
     output = []
     previous_val = None
+    # print(f"col_data['shlexed']: {col_data['shlexed']}")
     for i,d in enumerate(col_data['shlexed']):
         dl = d.lower()
         if previous_val == "not" and dl == "null":
@@ -391,7 +778,9 @@ def parse_col_comment(col_data):
 
 
     for s in col_data['shlexed']:
-        if s.startswith('comment'):
+        # s = s.lower()
+        # print(f"s: {s}")
+        if s.lower().startswith('comment'):
             # re.replace(r'^comment\s*')
             cmt = s.replace('comment','')
             col_data['comment'] = format.strip_any(cmt,[" "])
@@ -542,8 +931,6 @@ def parse_column_size(type_string):
                     return int(match[0])
     return None
 
-
-
 def strip_keys_constraints(sql):
     output = {
         "sql":[],
@@ -554,6 +941,7 @@ def strip_keys_constraints(sql):
     for line in lines:
         if len(line) == 0 or is_line_comment(line):
             continue
+        line = escape_quoted_commas(line)
         # print(f"line: {line}")
         if is_line_key(line):
             output['keys'].append(line)
@@ -620,111 +1008,145 @@ def parse_primary_keys(sql):
         # print(match)
     return primary_keys
 
-def strip_sql_quotes(sql):
+
+
+
+def format_sql_string(sql):
     '''
-        Remove all quotes from an sql string.
-        This includes these characters:
-        - Double Quote - "
-        - Single Quote - '
-        - Accent/Tick  - `
+        Format an SQL string to a consistent indentation.
 
         ----------
 
         Arguments
         -------------------------
-        `value` {str}
-            The string to strip of quotes.
+        `sql` {string}
+            The sql string to format.
 
-        Return {str}
+        Return {string}
         ----------------------
-        The string without quotations.
+        The formatted SQL
 
         Meta
         ----------
         `author`: Colemen Atwood
-        `created`: 05-31-2022 11:56:37
-        `memberOf`: parse_sql
+        `created`: 03-21-2022 12:38:32
         `version`: 1.0
-        `method_name`: strip_sql_quotes
-        @xxx [05-31-2022 11:58:02]: documentation for strip_sql_quotes
+        `method_name`: format_sql_string
+        @xxx [03-21-2022 12:38:41]: documentation for format_sql_string
+    '''
+    if cfu.file.exists(sql):
+        sql = cfu.file.read.read(sql)
+
+    sql = format.strip_empty_lines(sql)
+
+    raw = sql
+    # raw = re.sub(r'^[\n]*','',raw)
+    statements = sqlparse.split(raw)
+    new_contents = []
+    for state in statements:
+        state = re.sub(r'^[\s\n]*','',state)
+        new_state = sqlparse.format(state, reindent=True, keyword_case='upper')
+        new_contents.append(new_state)
+    if len(new_contents) > 0:
+        return "\n".join(new_contents)
+    return False
+
+
+
+
+def get_statements(sql):
+    '''
+        Parses the SQL statements from the string.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `sql` {string}
+            The sql string to parse.
+
+        Return {list}
+        ----------------------
+        A list of SQL statements.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-21-2022 12:40:52
+        `version`: 1.0
+        `method_name`: get_statements
+        @xxx [03-21-2022 12:40:58]: documentation for get_statements
     '''
 
 
-    sql = sql.replace("'",'')
-    sql = sql.replace('"','')
-    sql = sql.replace('`','')
-    return sql
+    raw = sql
+    if isinstance(sql,(str)):
+        if cfu.file.exists(sql):
+            raw = cfu.file.read.read(sql)
+
+    raw = strip_comments(raw)
+    raw = escape_quoted_chars(raw)
+    # raw = format_sql_string(raw)
+    statements = [x for x in sqlparse.parse(raw)]
+    return statements
+
+def determine_statement_purpose(statement):
+    statement_types = ["CREATE DATABASE","ALTER DATABASE","CREATE SCHEMA","CREATE INDEX","CREATE TABLE","ALTER TABLE","INSERT INTO","DROP INDEX","DROP TABLE","DELETE","UPDATE","SELECT",]
+    for s in statement_types:
+        if s in statement.upper():
+            return s
+
+    return None
 
 
-# def format_sql_string(sql):
-#     '''
-#         Format an SQL string to a consistent indentation.
 
-#         ----------
+def parse(sql):
+    if cfu.file.exists(sql):
+        sql = cfu.file.read.read(sql)
 
-#         Arguments
-#         -------------------------
-#         `sql` {string}
-#             The sql string to format.
+    if len(sql)== 0:
+        return None
 
-#         Return {string}
-#         ----------------------
-#         The formatted SQL
+    sql = format.strip_empty_lines(sql)
+    raw_statements = get_statements(sql)
+    data = {
+        "schemas":[],
+        "tables":[],
+        "statements":[],
+    }
 
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 03-21-2022 12:38:32
-#         `version`: 1.0
-#         `method_name`: format_sql_string
-#         @xxx [03-21-2022 12:38:41]: documentation for format_sql_string
-#     '''
+    for s in raw_statements:
+        s = s.value
+        # print(f"s: {s}")
+        state = {
+            "raw":s,
+            "purpose":determine_statement_purpose(s),
+            "data":None,
+        }
+        if state['purpose'] is None:
+            print(f"failed to determine purpose of statement:\n {s}")
+            continue
+
+        if state['purpose'] == "CREATE TABLE":
+            state['data'] = parse_table_statement(state['raw'])
+            obj.append(data['tables'],state['data'])
+            continue
+
+        # if state['purpose'] == "DROP TABLE":
+        #     state['data'] = parse_table_statement(state['raw'])
+
+        if state['purpose'] == "CREATE SCHEMA":
+            state['data'] = parse_schema_statement(state['raw'])
+            obj.append(data['schemas'],state['data'])
+            continue
+
+        data['statements'].append(state)
 
 
-#     raw = sql
-#     statements = sqlparse.split(raw)
-#     new_contents = []
-#     for state in statements:
-#         new_state = sqlparse.format(state, reindent=True, keyword_case='upper')
-#         new_contents.append(new_state)
-#     if len(new_contents) > 0:
-#         return "\n".join(new_contents)
-#     return False
 
-# def get_statements(sql):
-#     '''
-#         Parses the SQL statements from the string.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `sql` {string}
-#             The sql string to parse.
-
-#         Return {list}
-#         ----------------------
-#         A list of SQL statements.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 03-21-2022 12:40:52
-#         `version`: 1.0
-#         `method_name`: get_statements
-#         @xxx [03-21-2022 12:40:58]: documentation for get_statements
-#     '''
+    return data
 
 
-#     raw = sql
-#     if cfu.file.exists(sql):
-#         raw = cfu.file.read.read(sql)
-#     raw = strip_comments(raw)
-#     raw = format_sql_string(raw)
-#     return sqlparse.parse(raw)
-
-# def parse(sql):
-    
 
 
 # class Parse:
@@ -734,8 +1156,8 @@ def strip_sql_quotes(sql):
 #             "raw_sql":"",
 #             "file_path":ou.get_kwarg(['file path'],None,(str),**kwargs),
 #         }
-        
-    
+
+
 #     def read(self):
 #         if self.data['file_path'] is not None:
 #             if cfu.file.exists(self.data['file_path']):
